@@ -71,7 +71,7 @@ use Digest::MD5;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.2';
 
 use base qw(Lemonldap::NG::Common::CGI Exporter);
 our @ISA;
@@ -953,8 +953,6 @@ sub getPersistentSession {
         {
             storageModule        => $self->{persistentStorage},
             storageModuleOptions => $self->{persistentStorageOptions},
-            cacheModule          => $self->{localSessionStorage},
-            cacheModuleOptions   => $self->{localSessionStorageOptions},
             id                   => $pid,
             force                => 1,
             kind                 => "Persistent",
@@ -2085,6 +2083,8 @@ sub setSessionInfo {
 #@return Lemonldap::NG::Portal constant
 sub setMacros {
     my $self = shift;
+    $self->{sessionInfo}->{groups}  = '';
+    $self->{sessionInfo}->{hGroups} = {};
     foreach ( sort keys %{ $self->{macros} } ) {
         $self->{sessionInfo}->{$_} =
           $self->safe->reval( $self->{macros}->{$_} );
